# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['EntityArgs', 'Entity']

@pulumi.input_type
class EntityArgs:
    def __init__(__self__, *,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 external_policies: Optional[pulumi.Input[bool]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Entity resource.
        :param pulumi.Input[bool] disabled: True/false Is this entity currently disabled. Defaults to `false`
        :param pulumi.Input[bool] external_policies: `false` by default. If set to `true`, this resource will ignore any policies return from Vault or specified in the resource. You can use `identity.EntityPolicies` to manage policies for this entity in a decoupled manner.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: A Map of additional metadata to associate with the user.
        :param pulumi.Input[str] name: Name of the identity entity to create.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policies: A list of policies to apply to the entity.
        """
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)
        if external_policies is not None:
            pulumi.set(__self__, "external_policies", external_policies)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if policies is not None:
            pulumi.set(__self__, "policies", policies)

    @property
    @pulumi.getter
    def disabled(self) -> Optional[pulumi.Input[bool]]:
        """
        True/false Is this entity currently disabled. Defaults to `false`
        """
        return pulumi.get(self, "disabled")

    @disabled.setter
    def disabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disabled", value)

    @property
    @pulumi.getter(name="externalPolicies")
    def external_policies(self) -> Optional[pulumi.Input[bool]]:
        """
        `false` by default. If set to `true`, this resource will ignore any policies return from Vault or specified in the resource. You can use `identity.EntityPolicies` to manage policies for this entity in a decoupled manner.
        """
        return pulumi.get(self, "external_policies")

    @external_policies.setter
    def external_policies(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "external_policies", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A Map of additional metadata to associate with the user.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the identity entity to create.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of policies to apply to the entity.
        """
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "policies", value)


@pulumi.input_type
class _EntityState:
    def __init__(__self__, *,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 external_policies: Optional[pulumi.Input[bool]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering Entity resources.
        :param pulumi.Input[bool] disabled: True/false Is this entity currently disabled. Defaults to `false`
        :param pulumi.Input[bool] external_policies: `false` by default. If set to `true`, this resource will ignore any policies return from Vault or specified in the resource. You can use `identity.EntityPolicies` to manage policies for this entity in a decoupled manner.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: A Map of additional metadata to associate with the user.
        :param pulumi.Input[str] name: Name of the identity entity to create.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policies: A list of policies to apply to the entity.
        """
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)
        if external_policies is not None:
            pulumi.set(__self__, "external_policies", external_policies)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if policies is not None:
            pulumi.set(__self__, "policies", policies)

    @property
    @pulumi.getter
    def disabled(self) -> Optional[pulumi.Input[bool]]:
        """
        True/false Is this entity currently disabled. Defaults to `false`
        """
        return pulumi.get(self, "disabled")

    @disabled.setter
    def disabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disabled", value)

    @property
    @pulumi.getter(name="externalPolicies")
    def external_policies(self) -> Optional[pulumi.Input[bool]]:
        """
        `false` by default. If set to `true`, this resource will ignore any policies return from Vault or specified in the resource. You can use `identity.EntityPolicies` to manage policies for this entity in a decoupled manner.
        """
        return pulumi.get(self, "external_policies")

    @external_policies.setter
    def external_policies(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "external_policies", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A Map of additional metadata to associate with the user.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the identity entity to create.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of policies to apply to the entity.
        """
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "policies", value)


class Entity(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 external_policies: Optional[pulumi.Input[bool]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        test = vault.identity.Entity("test",
            metadata={
                "foo": "bar",
            },
            policies=["test"])
        ```

        ## Import

        Identity entity can be imported using the `id`, e.g.

        ```sh
         $ pulumi import vault:identity/entity:Entity test "ae6f8ued-0f1a-9f6b-2915-1a2be20dc053"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] disabled: True/false Is this entity currently disabled. Defaults to `false`
        :param pulumi.Input[bool] external_policies: `false` by default. If set to `true`, this resource will ignore any policies return from Vault or specified in the resource. You can use `identity.EntityPolicies` to manage policies for this entity in a decoupled manner.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: A Map of additional metadata to associate with the user.
        :param pulumi.Input[str] name: Name of the identity entity to create.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policies: A list of policies to apply to the entity.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[EntityArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        test = vault.identity.Entity("test",
            metadata={
                "foo": "bar",
            },
            policies=["test"])
        ```

        ## Import

        Identity entity can be imported using the `id`, e.g.

        ```sh
         $ pulumi import vault:identity/entity:Entity test "ae6f8ued-0f1a-9f6b-2915-1a2be20dc053"
        ```

        :param str resource_name: The name of the resource.
        :param EntityArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EntityArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 external_policies: Optional[pulumi.Input[bool]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EntityArgs.__new__(EntityArgs)

            __props__.__dict__["disabled"] = disabled
            __props__.__dict__["external_policies"] = external_policies
            __props__.__dict__["metadata"] = metadata
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["policies"] = policies
        super(Entity, __self__).__init__(
            'vault:identity/entity:Entity',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            disabled: Optional[pulumi.Input[bool]] = None,
            external_policies: Optional[pulumi.Input[bool]] = None,
            metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            policies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'Entity':
        """
        Get an existing Entity resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] disabled: True/false Is this entity currently disabled. Defaults to `false`
        :param pulumi.Input[bool] external_policies: `false` by default. If set to `true`, this resource will ignore any policies return from Vault or specified in the resource. You can use `identity.EntityPolicies` to manage policies for this entity in a decoupled manner.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: A Map of additional metadata to associate with the user.
        :param pulumi.Input[str] name: Name of the identity entity to create.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policies: A list of policies to apply to the entity.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EntityState.__new__(_EntityState)

        __props__.__dict__["disabled"] = disabled
        __props__.__dict__["external_policies"] = external_policies
        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["policies"] = policies
        return Entity(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def disabled(self) -> pulumi.Output[Optional[bool]]:
        """
        True/false Is this entity currently disabled. Defaults to `false`
        """
        return pulumi.get(self, "disabled")

    @property
    @pulumi.getter(name="externalPolicies")
    def external_policies(self) -> pulumi.Output[Optional[bool]]:
        """
        `false` by default. If set to `true`, this resource will ignore any policies return from Vault or specified in the resource. You can use `identity.EntityPolicies` to manage policies for this entity in a decoupled manner.
        """
        return pulumi.get(self, "external_policies")

    @property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A Map of additional metadata to associate with the user.
        """
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the identity entity to create.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def policies(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of policies to apply to the entity.
        """
        return pulumi.get(self, "policies")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .audit import *
from .audit_request_header import *
from .auth_backend import *
from .cert_auth_backend_role import *
from .egp_policy import *
from .get_auth_backend import *
from .get_auth_backends import *
from .get_nomad_access_token import *
from .get_policy_document import *
from .get_raft_autopilot_state import *
from .mfa_duo import *
from .mfa_okta import *
from .mfa_pingid import *
from .mfa_totp import *
from .mount import *
from .namespace import *
from .nomad_secret_backend import *
from .nomad_secret_role import *
from .password_policy import *
from .policy import *
from .provider import *
from .quota_lease_count import *
from .quota_rate_limit import *
from .raft_autopilot import *
from .raft_snapshot_agent_config import *
from .rgp_policy import *
from .token import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_vault.ad as __ad
    ad = __ad
    import pulumi_vault.alicloud as __alicloud
    alicloud = __alicloud
    import pulumi_vault.approle as __approle
    approle = __approle
    import pulumi_vault.aws as __aws
    aws = __aws
    import pulumi_vault.azure as __azure
    azure = __azure
    import pulumi_vault.config as __config
    config = __config
    import pulumi_vault.consul as __consul
    consul = __consul
    import pulumi_vault.database as __database
    database = __database
    import pulumi_vault.gcp as __gcp
    gcp = __gcp
    import pulumi_vault.generic as __generic
    generic = __generic
    import pulumi_vault.github as __github
    github = __github
    import pulumi_vault.identity as __identity
    identity = __identity
    import pulumi_vault.jwt as __jwt
    jwt = __jwt
    import pulumi_vault.kmip as __kmip
    kmip = __kmip
    import pulumi_vault.kubernetes as __kubernetes
    kubernetes = __kubernetes
    import pulumi_vault.kv as __kv
    kv = __kv
    import pulumi_vault.ldap as __ldap
    ldap = __ldap
    import pulumi_vault.managed as __managed
    managed = __managed
    import pulumi_vault.mongodbatlas as __mongodbatlas
    mongodbatlas = __mongodbatlas
    import pulumi_vault.okta as __okta
    okta = __okta
    import pulumi_vault.pkisecret as __pkisecret
    pkisecret = __pkisecret
    import pulumi_vault.rabbitmq as __rabbitmq
    rabbitmq = __rabbitmq
    import pulumi_vault.saml as __saml
    saml = __saml
    import pulumi_vault.ssh as __ssh
    ssh = __ssh
    import pulumi_vault.terraformcloud as __terraformcloud
    terraformcloud = __terraformcloud
    import pulumi_vault.tokenauth as __tokenauth
    tokenauth = __tokenauth
    import pulumi_vault.transform as __transform
    transform = __transform
    import pulumi_vault.transit as __transit
    transit = __transit
else:
    ad = _utilities.lazy_import('pulumi_vault.ad')
    alicloud = _utilities.lazy_import('pulumi_vault.alicloud')
    approle = _utilities.lazy_import('pulumi_vault.approle')
    aws = _utilities.lazy_import('pulumi_vault.aws')
    azure = _utilities.lazy_import('pulumi_vault.azure')
    config = _utilities.lazy_import('pulumi_vault.config')
    consul = _utilities.lazy_import('pulumi_vault.consul')
    database = _utilities.lazy_import('pulumi_vault.database')
    gcp = _utilities.lazy_import('pulumi_vault.gcp')
    generic = _utilities.lazy_import('pulumi_vault.generic')
    github = _utilities.lazy_import('pulumi_vault.github')
    identity = _utilities.lazy_import('pulumi_vault.identity')
    jwt = _utilities.lazy_import('pulumi_vault.jwt')
    kmip = _utilities.lazy_import('pulumi_vault.kmip')
    kubernetes = _utilities.lazy_import('pulumi_vault.kubernetes')
    kv = _utilities.lazy_import('pulumi_vault.kv')
    ldap = _utilities.lazy_import('pulumi_vault.ldap')
    managed = _utilities.lazy_import('pulumi_vault.managed')
    mongodbatlas = _utilities.lazy_import('pulumi_vault.mongodbatlas')
    okta = _utilities.lazy_import('pulumi_vault.okta')
    pkisecret = _utilities.lazy_import('pulumi_vault.pkisecret')
    rabbitmq = _utilities.lazy_import('pulumi_vault.rabbitmq')
    saml = _utilities.lazy_import('pulumi_vault.saml')
    ssh = _utilities.lazy_import('pulumi_vault.ssh')
    terraformcloud = _utilities.lazy_import('pulumi_vault.terraformcloud')
    tokenauth = _utilities.lazy_import('pulumi_vault.tokenauth')
    transform = _utilities.lazy_import('pulumi_vault.transform')
    transit = _utilities.lazy_import('pulumi_vault.transit')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "vault",
  "mod": "ad/secretBackend",
  "fqn": "pulumi_vault.ad",
  "classes": {
   "vault:ad/secretBackend:SecretBackend": "SecretBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "ad/secretLibrary",
  "fqn": "pulumi_vault.ad",
  "classes": {
   "vault:ad/secretLibrary:SecretLibrary": "SecretLibrary"
  }
 },
 {
  "pkg": "vault",
  "mod": "ad/secretRole",
  "fqn": "pulumi_vault.ad",
  "classes": {
   "vault:ad/secretRole:SecretRole": "SecretRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "alicloud/authBackendRole",
  "fqn": "pulumi_vault.alicloud",
  "classes": {
   "vault:alicloud/authBackendRole:AuthBackendRole": "AuthBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "appRole/authBackendLogin",
  "fqn": "pulumi_vault.approle",
  "classes": {
   "vault:appRole/authBackendLogin:AuthBackendLogin": "AuthBackendLogin"
  }
 },
 {
  "pkg": "vault",
  "mod": "appRole/authBackendRole",
  "fqn": "pulumi_vault.approle",
  "classes": {
   "vault:appRole/authBackendRole:AuthBackendRole": "AuthBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "appRole/authBackendRoleSecretId",
  "fqn": "pulumi_vault.approle",
  "classes": {
   "vault:appRole/authBackendRoleSecretId:AuthBackendRoleSecretId": "AuthBackendRoleSecretId"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/authBackendCert",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/authBackendCert:AuthBackendCert": "AuthBackendCert"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/authBackendClient",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/authBackendClient:AuthBackendClient": "AuthBackendClient"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/authBackendConfigIdentity",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/authBackendConfigIdentity:AuthBackendConfigIdentity": "AuthBackendConfigIdentity"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/authBackendIdentityWhitelist",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/authBackendIdentityWhitelist:AuthBackendIdentityWhitelist": "AuthBackendIdentityWhitelist"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/authBackendLogin",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/authBackendLogin:AuthBackendLogin": "AuthBackendLogin"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/authBackendRole",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/authBackendRole:AuthBackendRole": "AuthBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/authBackendRoleTag",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/authBackendRoleTag:AuthBackendRoleTag": "AuthBackendRoleTag"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/authBackendRoletagBlacklist",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/authBackendRoletagBlacklist:AuthBackendRoletagBlacklist": "AuthBackendRoletagBlacklist"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/authBackendStsRole",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/authBackendStsRole:AuthBackendStsRole": "AuthBackendStsRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/secretBackend",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/secretBackend:SecretBackend": "SecretBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/secretBackendRole",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/secretBackendRole:SecretBackendRole": "SecretBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "aws/secretBackendStaticRole",
  "fqn": "pulumi_vault.aws",
  "classes": {
   "vault:aws/secretBackendStaticRole:SecretBackendStaticRole": "SecretBackendStaticRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "azure/authBackendConfig",
  "fqn": "pulumi_vault.azure",
  "classes": {
   "vault:azure/authBackendConfig:AuthBackendConfig": "AuthBackendConfig"
  }
 },
 {
  "pkg": "vault",
  "mod": "azure/authBackendRole",
  "fqn": "pulumi_vault.azure",
  "classes": {
   "vault:azure/authBackendRole:AuthBackendRole": "AuthBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "azure/backend",
  "fqn": "pulumi_vault.azure",
  "classes": {
   "vault:azure/backend:Backend": "Backend"
  }
 },
 {
  "pkg": "vault",
  "mod": "azure/backendRole",
  "fqn": "pulumi_vault.azure",
  "classes": {
   "vault:azure/backendRole:BackendRole": "BackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "consul/secretBackend",
  "fqn": "pulumi_vault.consul",
  "classes": {
   "vault:consul/secretBackend:SecretBackend": "SecretBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "consul/secretBackendRole",
  "fqn": "pulumi_vault.consul",
  "classes": {
   "vault:consul/secretBackendRole:SecretBackendRole": "SecretBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "database/secretBackendConnection",
  "fqn": "pulumi_vault.database",
  "classes": {
   "vault:database/secretBackendConnection:SecretBackendConnection": "SecretBackendConnection"
  }
 },
 {
  "pkg": "vault",
  "mod": "database/secretBackendRole",
  "fqn": "pulumi_vault.database",
  "classes": {
   "vault:database/secretBackendRole:SecretBackendRole": "SecretBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "database/secretBackendStaticRole",
  "fqn": "pulumi_vault.database",
  "classes": {
   "vault:database/secretBackendStaticRole:SecretBackendStaticRole": "SecretBackendStaticRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "database/secretsMount",
  "fqn": "pulumi_vault.database",
  "classes": {
   "vault:database/secretsMount:SecretsMount": "SecretsMount"
  }
 },
 {
  "pkg": "vault",
  "mod": "gcp/authBackend",
  "fqn": "pulumi_vault.gcp",
  "classes": {
   "vault:gcp/authBackend:AuthBackend": "AuthBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "gcp/authBackendRole",
  "fqn": "pulumi_vault.gcp",
  "classes": {
   "vault:gcp/authBackendRole:AuthBackendRole": "AuthBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "gcp/secretBackend",
  "fqn": "pulumi_vault.gcp",
  "classes": {
   "vault:gcp/secretBackend:SecretBackend": "SecretBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "gcp/secretImpersonatedAccount",
  "fqn": "pulumi_vault.gcp",
  "classes": {
   "vault:gcp/secretImpersonatedAccount:SecretImpersonatedAccount": "SecretImpersonatedAccount"
  }
 },
 {
  "pkg": "vault",
  "mod": "gcp/secretRoleset",
  "fqn": "pulumi_vault.gcp",
  "classes": {
   "vault:gcp/secretRoleset:SecretRoleset": "SecretRoleset"
  }
 },
 {
  "pkg": "vault",
  "mod": "gcp/secretStaticAccount",
  "fqn": "pulumi_vault.gcp",
  "classes": {
   "vault:gcp/secretStaticAccount:SecretStaticAccount": "SecretStaticAccount"
  }
 },
 {
  "pkg": "vault",
  "mod": "generic/endpoint",
  "fqn": "pulumi_vault.generic",
  "classes": {
   "vault:generic/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "vault",
  "mod": "generic/secret",
  "fqn": "pulumi_vault.generic",
  "classes": {
   "vault:generic/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "vault",
  "mod": "github/authBackend",
  "fqn": "pulumi_vault.github",
  "classes": {
   "vault:github/authBackend:AuthBackend": "AuthBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "github/team",
  "fqn": "pulumi_vault.github",
  "classes": {
   "vault:github/team:Team": "Team"
  }
 },
 {
  "pkg": "vault",
  "mod": "github/user",
  "fqn": "pulumi_vault.github",
  "classes": {
   "vault:github/user:User": "User"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/entity",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/entity:Entity": "Entity"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/entityAlias",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/entityAlias:EntityAlias": "EntityAlias"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/entityPolicies",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/entityPolicies:EntityPolicies": "EntityPolicies"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/group",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/group:Group": "Group"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/groupAlias",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/groupAlias:GroupAlias": "GroupAlias"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/groupMemberEntityIds",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/groupMemberEntityIds:GroupMemberEntityIds": "GroupMemberEntityIds"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/groupMemberGroupIds",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/groupMemberGroupIds:GroupMemberGroupIds": "GroupMemberGroupIds"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/groupPolicies",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/groupPolicies:GroupPolicies": "GroupPolicies"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/mfaDuo",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/mfaDuo:MfaDuo": "MfaDuo"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/mfaLoginEnforcement",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/mfaLoginEnforcement:MfaLoginEnforcement": "MfaLoginEnforcement"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/mfaOkta",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/mfaOkta:MfaOkta": "MfaOkta"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/mfaPingid",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/mfaPingid:MfaPingid": "MfaPingid"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/mfaTotp",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/mfaTotp:MfaTotp": "MfaTotp"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/oidc",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/oidc:Oidc": "Oidc"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/oidcAssignment",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/oidcAssignment:OidcAssignment": "OidcAssignment"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/oidcClient",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/oidcClient:OidcClient": "OidcClient"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/oidcKey",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/oidcKey:OidcKey": "OidcKey"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/oidcKeyAllowedClientID",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/oidcKeyAllowedClientID:OidcKeyAllowedClientID": "OidcKeyAllowedClientID"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/oidcProvider",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/oidcProvider:OidcProvider": "OidcProvider"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/oidcRole",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/oidcRole:OidcRole": "OidcRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "identity/oidcScope",
  "fqn": "pulumi_vault.identity",
  "classes": {
   "vault:identity/oidcScope:OidcScope": "OidcScope"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/audit",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/audit:Audit": "Audit"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/auditRequestHeader",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/auditRequestHeader:AuditRequestHeader": "AuditRequestHeader"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/authBackend",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/authBackend:AuthBackend": "AuthBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/certAuthBackendRole",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/certAuthBackendRole:CertAuthBackendRole": "CertAuthBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/egpPolicy",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/egpPolicy:EgpPolicy": "EgpPolicy"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/mfaDuo",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/mfaDuo:MfaDuo": "MfaDuo"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/mfaOkta",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/mfaOkta:MfaOkta": "MfaOkta"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/mfaPingid",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/mfaPingid:MfaPingid": "MfaPingid"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/mfaTotp",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/mfaTotp:MfaTotp": "MfaTotp"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/mount",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/mount:Mount": "Mount"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/namespace",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/nomadSecretBackend",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/nomadSecretBackend:NomadSecretBackend": "NomadSecretBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/nomadSecretRole",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/nomadSecretRole:NomadSecretRole": "NomadSecretRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/passwordPolicy",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/passwordPolicy:PasswordPolicy": "PasswordPolicy"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/policy",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/quotaLeaseCount",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/quotaLeaseCount:QuotaLeaseCount": "QuotaLeaseCount"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/quotaRateLimit",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/quotaRateLimit:QuotaRateLimit": "QuotaRateLimit"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/raftAutopilot",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/raftAutopilot:RaftAutopilot": "RaftAutopilot"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/raftSnapshotAgentConfig",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/raftSnapshotAgentConfig:RaftSnapshotAgentConfig": "RaftSnapshotAgentConfig"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/rgpPolicy",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/rgpPolicy:RgpPolicy": "RgpPolicy"
  }
 },
 {
  "pkg": "vault",
  "mod": "index/token",
  "fqn": "pulumi_vault",
  "classes": {
   "vault:index/token:Token": "Token"
  }
 },
 {
  "pkg": "vault",
  "mod": "jwt/authBackend",
  "fqn": "pulumi_vault.jwt",
  "classes": {
   "vault:jwt/authBackend:AuthBackend": "AuthBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "jwt/authBackendRole",
  "fqn": "pulumi_vault.jwt",
  "classes": {
   "vault:jwt/authBackendRole:AuthBackendRole": "AuthBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "kmip/secretBackend",
  "fqn": "pulumi_vault.kmip",
  "classes": {
   "vault:kmip/secretBackend:SecretBackend": "SecretBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "kmip/secretRole",
  "fqn": "pulumi_vault.kmip",
  "classes": {
   "vault:kmip/secretRole:SecretRole": "SecretRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "kmip/secretScope",
  "fqn": "pulumi_vault.kmip",
  "classes": {
   "vault:kmip/secretScope:SecretScope": "SecretScope"
  }
 },
 {
  "pkg": "vault",
  "mod": "kubernetes/authBackendConfig",
  "fqn": "pulumi_vault.kubernetes",
  "classes": {
   "vault:kubernetes/authBackendConfig:AuthBackendConfig": "AuthBackendConfig"
  }
 },
 {
  "pkg": "vault",
  "mod": "kubernetes/authBackendRole",
  "fqn": "pulumi_vault.kubernetes",
  "classes": {
   "vault:kubernetes/authBackendRole:AuthBackendRole": "AuthBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "kubernetes/secretBackend",
  "fqn": "pulumi_vault.kubernetes",
  "classes": {
   "vault:kubernetes/secretBackend:SecretBackend": "SecretBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "kubernetes/secretBackendRole",
  "fqn": "pulumi_vault.kubernetes",
  "classes": {
   "vault:kubernetes/secretBackendRole:SecretBackendRole": "SecretBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "kv/secret",
  "fqn": "pulumi_vault.kv",
  "classes": {
   "vault:kv/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "vault",
  "mod": "kv/secretBackendV2",
  "fqn": "pulumi_vault.kv",
  "classes": {
   "vault:kv/secretBackendV2:SecretBackendV2": "SecretBackendV2"
  }
 },
 {
  "pkg": "vault",
  "mod": "kv/secretV2",
  "fqn": "pulumi_vault.kv",
  "classes": {
   "vault:kv/secretV2:SecretV2": "SecretV2"
  }
 },
 {
  "pkg": "vault",
  "mod": "ldap/authBackend",
  "fqn": "pulumi_vault.ldap",
  "classes": {
   "vault:ldap/authBackend:AuthBackend": "AuthBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "ldap/authBackendGroup",
  "fqn": "pulumi_vault.ldap",
  "classes": {
   "vault:ldap/authBackendGroup:AuthBackendGroup": "AuthBackendGroup"
  }
 },
 {
  "pkg": "vault",
  "mod": "ldap/authBackendUser",
  "fqn": "pulumi_vault.ldap",
  "classes": {
   "vault:ldap/authBackendUser:AuthBackendUser": "AuthBackendUser"
  }
 },
 {
  "pkg": "vault",
  "mod": "ldap/secretBackend",
  "fqn": "pulumi_vault.ldap",
  "classes": {
   "vault:ldap/secretBackend:SecretBackend": "SecretBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "ldap/secretBackendDynamicRole",
  "fqn": "pulumi_vault.ldap",
  "classes": {
   "vault:ldap/secretBackendDynamicRole:SecretBackendDynamicRole": "SecretBackendDynamicRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "ldap/secretBackendLibrarySet",
  "fqn": "pulumi_vault.ldap",
  "classes": {
   "vault:ldap/secretBackendLibrarySet:SecretBackendLibrarySet": "SecretBackendLibrarySet"
  }
 },
 {
  "pkg": "vault",
  "mod": "ldap/secretBackendStaticRole",
  "fqn": "pulumi_vault.ldap",
  "classes": {
   "vault:ldap/secretBackendStaticRole:SecretBackendStaticRole": "SecretBackendStaticRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "managed/keys",
  "fqn": "pulumi_vault.managed",
  "classes": {
   "vault:managed/keys:Keys": "Keys"
  }
 },
 {
  "pkg": "vault",
  "mod": "mongodbatlas/secretBackend",
  "fqn": "pulumi_vault.mongodbatlas",
  "classes": {
   "vault:mongodbatlas/secretBackend:SecretBackend": "SecretBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "mongodbatlas/secretRole",
  "fqn": "pulumi_vault.mongodbatlas",
  "classes": {
   "vault:mongodbatlas/secretRole:SecretRole": "SecretRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "okta/authBackend",
  "fqn": "pulumi_vault.okta",
  "classes": {
   "vault:okta/authBackend:AuthBackend": "AuthBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "okta/authBackendGroup",
  "fqn": "pulumi_vault.okta",
  "classes": {
   "vault:okta/authBackendGroup:AuthBackendGroup": "AuthBackendGroup"
  }
 },
 {
  "pkg": "vault",
  "mod": "okta/authBackendUser",
  "fqn": "pulumi_vault.okta",
  "classes": {
   "vault:okta/authBackendUser:AuthBackendUser": "AuthBackendUser"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendCert",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendCert:SecretBackendCert": "SecretBackendCert"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendConfigCa",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendConfigCa:SecretBackendConfigCa": "SecretBackendConfigCa"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendConfigIssuers",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendConfigIssuers:SecretBackendConfigIssuers": "SecretBackendConfigIssuers"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendConfigUrls",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendConfigUrls:SecretBackendConfigUrls": "SecretBackendConfigUrls"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendCrlConfig",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendCrlConfig:SecretBackendCrlConfig": "SecretBackendCrlConfig"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendIntermediateCertRequest",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendIntermediateCertRequest:SecretBackendIntermediateCertRequest": "SecretBackendIntermediateCertRequest"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendIntermediateSetSigned",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendIntermediateSetSigned:SecretBackendIntermediateSetSigned": "SecretBackendIntermediateSetSigned"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendIssuer",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendIssuer:SecretBackendIssuer": "SecretBackendIssuer"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendKey",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendKey:SecretBackendKey": "SecretBackendKey"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendRole",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendRole:SecretBackendRole": "SecretBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendRootCert",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendRootCert:SecretBackendRootCert": "SecretBackendRootCert"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendRootSignIntermediate",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendRootSignIntermediate:SecretBackendRootSignIntermediate": "SecretBackendRootSignIntermediate"
  }
 },
 {
  "pkg": "vault",
  "mod": "pkiSecret/secretBackendSign",
  "fqn": "pulumi_vault.pkisecret",
  "classes": {
   "vault:pkiSecret/secretBackendSign:SecretBackendSign": "SecretBackendSign"
  }
 },
 {
  "pkg": "vault",
  "mod": "rabbitMq/secretBackend",
  "fqn": "pulumi_vault.rabbitmq",
  "classes": {
   "vault:rabbitMq/secretBackend:SecretBackend": "SecretBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "rabbitMq/secretBackendRole",
  "fqn": "pulumi_vault.rabbitmq",
  "classes": {
   "vault:rabbitMq/secretBackendRole:SecretBackendRole": "SecretBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "saml/authBackend",
  "fqn": "pulumi_vault.saml",
  "classes": {
   "vault:saml/authBackend:AuthBackend": "AuthBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "saml/authBackendRole",
  "fqn": "pulumi_vault.saml",
  "classes": {
   "vault:saml/authBackendRole:AuthBackendRole": "AuthBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "ssh/secretBackendCa",
  "fqn": "pulumi_vault.ssh",
  "classes": {
   "vault:ssh/secretBackendCa:SecretBackendCa": "SecretBackendCa"
  }
 },
 {
  "pkg": "vault",
  "mod": "ssh/secretBackendRole",
  "fqn": "pulumi_vault.ssh",
  "classes": {
   "vault:ssh/secretBackendRole:SecretBackendRole": "SecretBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "terraformcloud/secretBackend",
  "fqn": "pulumi_vault.terraformcloud",
  "classes": {
   "vault:terraformcloud/secretBackend:SecretBackend": "SecretBackend"
  }
 },
 {
  "pkg": "vault",
  "mod": "terraformcloud/secretCreds",
  "fqn": "pulumi_vault.terraformcloud",
  "classes": {
   "vault:terraformcloud/secretCreds:SecretCreds": "SecretCreds"
  }
 },
 {
  "pkg": "vault",
  "mod": "terraformcloud/secretRole",
  "fqn": "pulumi_vault.terraformcloud",
  "classes": {
   "vault:terraformcloud/secretRole:SecretRole": "SecretRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "tokenauth/authBackendRole",
  "fqn": "pulumi_vault.tokenauth",
  "classes": {
   "vault:tokenauth/authBackendRole:AuthBackendRole": "AuthBackendRole"
  }
 },
 {
  "pkg": "vault",
  "mod": "transform/alphabet",
  "fqn": "pulumi_vault.transform",
  "classes": {
   "vault:transform/alphabet:Alphabet": "Alphabet"
  }
 },
 {
  "pkg": "vault",
  "mod": "transform/role",
  "fqn": "pulumi_vault.transform",
  "classes": {
   "vault:transform/role:Role": "Role"
  }
 },
 {
  "pkg": "vault",
  "mod": "transform/template",
  "fqn": "pulumi_vault.transform",
  "classes": {
   "vault:transform/template:Template": "Template"
  }
 },
 {
  "pkg": "vault",
  "mod": "transform/transformation",
  "fqn": "pulumi_vault.transform",
  "classes": {
   "vault:transform/transformation:Transformation": "Transformation"
  }
 },
 {
  "pkg": "vault",
  "mod": "transit/secretBackendKey",
  "fqn": "pulumi_vault.transit",
  "classes": {
   "vault:transit/secretBackendKey:SecretBackendKey": "SecretBackendKey"
  }
 },
 {
  "pkg": "vault",
  "mod": "transit/secretCacheConfig",
  "fqn": "pulumi_vault.transit",
  "classes": {
   "vault:transit/secretCacheConfig:SecretCacheConfig": "SecretCacheConfig"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "vault",
  "token": "pulumi:providers:vault",
  "fqn": "pulumi_vault",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AuthBackendArgs', 'AuthBackend']

@pulumi.input_type
class AuthBackendArgs:
    def __init__(__self__, *,
                 bound_issuer: Optional[pulumi.Input[str]] = None,
                 default_role: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disable_remount: Optional[pulumi.Input[bool]] = None,
                 jwks_ca_pem: Optional[pulumi.Input[str]] = None,
                 jwks_url: Optional[pulumi.Input[str]] = None,
                 jwt_supported_algs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 jwt_validation_pubkeys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 local: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 namespace_in_state: Optional[pulumi.Input[bool]] = None,
                 oidc_client_id: Optional[pulumi.Input[str]] = None,
                 oidc_client_secret: Optional[pulumi.Input[str]] = None,
                 oidc_discovery_ca_pem: Optional[pulumi.Input[str]] = None,
                 oidc_discovery_url: Optional[pulumi.Input[str]] = None,
                 oidc_response_mode: Optional[pulumi.Input[str]] = None,
                 oidc_response_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 provider_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tune: Optional[pulumi.Input['AuthBackendTuneArgs']] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AuthBackend resource.
        :param pulumi.Input[str] bound_issuer: The value against which to match the iss claim in a JWT
        :param pulumi.Input[str] default_role: The default role to use if none is provided during login
        :param pulumi.Input[str] description: The description of the auth backend
        :param pulumi.Input[bool] disable_remount: If set, opts out of mount migration on path updates.
               See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        :param pulumi.Input[str] jwks_ca_pem: The CA certificate or chain of certificates, in PEM format, to use to validate connections to the JWKS URL. If not set, system certificates are used.
        :param pulumi.Input[str] jwks_url: JWKS URL to use to authenticate signatures. Cannot be used with "oidc_discovery_url" or "jwt_validation_pubkeys".
        :param pulumi.Input[Sequence[pulumi.Input[str]]] jwt_supported_algs: A list of supported signing algorithms. Vault 1.1.0 defaults to [RS256] but future or past versions of Vault may differ
        :param pulumi.Input[Sequence[pulumi.Input[str]]] jwt_validation_pubkeys: A list of PEM-encoded public keys to use to authenticate signatures locally. Cannot be used in combination with `oidc_discovery_url`
        :param pulumi.Input[bool] local: Specifies if the auth method is local only.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] namespace_in_state: Pass namespace in the OIDC state parameter instead of as a separate query parameter. With this setting, the allowed redirect URL(s) in Vault and on the provider side should not contain a namespace query parameter. This means only one redirect URL entry needs to be maintained on the OIDC provider side for all vault namespaces that will be authenticating against it. Defaults to true for new configs
               
               * tune - (Optional) Extra configuration block. Structure is documented below.
               
               The `tune` block is used to tune the auth backend:
        :param pulumi.Input[str] oidc_client_id: Client ID used for OIDC backends
        :param pulumi.Input[str] oidc_client_secret: Client Secret used for OIDC backends
        :param pulumi.Input[str] oidc_discovery_ca_pem: The CA certificate or chain of certificates, in PEM format, to use to validate connections to the OIDC Discovery URL. If not set, system certificates are used
        :param pulumi.Input[str] oidc_discovery_url: The OIDC Discovery URL, without any .well-known component (base path). Cannot be used in combination with `jwt_validation_pubkeys`
        :param pulumi.Input[str] oidc_response_mode: The response mode to be used in the OAuth2 request. Allowed values are `query` and `form_post`. Defaults to `query`. If using Vault namespaces, and `oidc_response_mode` is `form_post`, then `namespace_in_state` should be set to `false`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] oidc_response_types: List of response types to request. Allowed values are 'code' and 'id_token'. Defaults to `["code"]`. Note: `id_token` may only be used if `oidc_response_mode` is set to `form_post`.
        :param pulumi.Input[str] path: Path to mount the JWT/OIDC auth backend
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] provider_config: Provider specific handling configuration. All values may be strings, and the provider will convert to the appropriate type when configuring Vault.
        :param pulumi.Input[str] type: Type of auth backend. Should be one of `jwt` or `oidc`. Default - `jwt`
        """
        if bound_issuer is not None:
            pulumi.set(__self__, "bound_issuer", bound_issuer)
        if default_role is not None:
            pulumi.set(__self__, "default_role", default_role)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disable_remount is not None:
            pulumi.set(__self__, "disable_remount", disable_remount)
        if jwks_ca_pem is not None:
            pulumi.set(__self__, "jwks_ca_pem", jwks_ca_pem)
        if jwks_url is not None:
            pulumi.set(__self__, "jwks_url", jwks_url)
        if jwt_supported_algs is not None:
            pulumi.set(__self__, "jwt_supported_algs", jwt_supported_algs)
        if jwt_validation_pubkeys is not None:
            pulumi.set(__self__, "jwt_validation_pubkeys", jwt_validation_pubkeys)
        if local is not None:
            pulumi.set(__self__, "local", local)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if namespace_in_state is not None:
            pulumi.set(__self__, "namespace_in_state", namespace_in_state)
        if oidc_client_id is not None:
            pulumi.set(__self__, "oidc_client_id", oidc_client_id)
        if oidc_client_secret is not None:
            pulumi.set(__self__, "oidc_client_secret", oidc_client_secret)
        if oidc_discovery_ca_pem is not None:
            pulumi.set(__self__, "oidc_discovery_ca_pem", oidc_discovery_ca_pem)
        if oidc_discovery_url is not None:
            pulumi.set(__self__, "oidc_discovery_url", oidc_discovery_url)
        if oidc_response_mode is not None:
            pulumi.set(__self__, "oidc_response_mode", oidc_response_mode)
        if oidc_response_types is not None:
            pulumi.set(__self__, "oidc_response_types", oidc_response_types)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if tune is not None:
            pulumi.set(__self__, "tune", tune)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="boundIssuer")
    def bound_issuer(self) -> Optional[pulumi.Input[str]]:
        """
        The value against which to match the iss claim in a JWT
        """
        return pulumi.get(self, "bound_issuer")

    @bound_issuer.setter
    def bound_issuer(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bound_issuer", value)

    @property
    @pulumi.getter(name="defaultRole")
    def default_role(self) -> Optional[pulumi.Input[str]]:
        """
        The default role to use if none is provided during login
        """
        return pulumi.get(self, "default_role")

    @default_role.setter
    def default_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_role", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the auth backend
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="disableRemount")
    def disable_remount(self) -> Optional[pulumi.Input[bool]]:
        """
        If set, opts out of mount migration on path updates.
        See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        """
        return pulumi.get(self, "disable_remount")

    @disable_remount.setter
    def disable_remount(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disable_remount", value)

    @property
    @pulumi.getter(name="jwksCaPem")
    def jwks_ca_pem(self) -> Optional[pulumi.Input[str]]:
        """
        The CA certificate or chain of certificates, in PEM format, to use to validate connections to the JWKS URL. If not set, system certificates are used.
        """
        return pulumi.get(self, "jwks_ca_pem")

    @jwks_ca_pem.setter
    def jwks_ca_pem(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jwks_ca_pem", value)

    @property
    @pulumi.getter(name="jwksUrl")
    def jwks_url(self) -> Optional[pulumi.Input[str]]:
        """
        JWKS URL to use to authenticate signatures. Cannot be used with "oidc_discovery_url" or "jwt_validation_pubkeys".
        """
        return pulumi.get(self, "jwks_url")

    @jwks_url.setter
    def jwks_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jwks_url", value)

    @property
    @pulumi.getter(name="jwtSupportedAlgs")
    def jwt_supported_algs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of supported signing algorithms. Vault 1.1.0 defaults to [RS256] but future or past versions of Vault may differ
        """
        return pulumi.get(self, "jwt_supported_algs")

    @jwt_supported_algs.setter
    def jwt_supported_algs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "jwt_supported_algs", value)

    @property
    @pulumi.getter(name="jwtValidationPubkeys")
    def jwt_validation_pubkeys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of PEM-encoded public keys to use to authenticate signatures locally. Cannot be used in combination with `oidc_discovery_url`
        """
        return pulumi.get(self, "jwt_validation_pubkeys")

    @jwt_validation_pubkeys.setter
    def jwt_validation_pubkeys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "jwt_validation_pubkeys", value)

    @property
    @pulumi.getter
    def local(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies if the auth method is local only.
        """
        return pulumi.get(self, "local")

    @local.setter
    def local(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "local", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="namespaceInState")
    def namespace_in_state(self) -> Optional[pulumi.Input[bool]]:
        """
        Pass namespace in the OIDC state parameter instead of as a separate query parameter. With this setting, the allowed redirect URL(s) in Vault and on the provider side should not contain a namespace query parameter. This means only one redirect URL entry needs to be maintained on the OIDC provider side for all vault namespaces that will be authenticating against it. Defaults to true for new configs

        * tune - (Optional) Extra configuration block. Structure is documented below.

        The `tune` block is used to tune the auth backend:
        """
        return pulumi.get(self, "namespace_in_state")

    @namespace_in_state.setter
    def namespace_in_state(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "namespace_in_state", value)

    @property
    @pulumi.getter(name="oidcClientId")
    def oidc_client_id(self) -> Optional[pulumi.Input[str]]:
        """
        Client ID used for OIDC backends
        """
        return pulumi.get(self, "oidc_client_id")

    @oidc_client_id.setter
    def oidc_client_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_client_id", value)

    @property
    @pulumi.getter(name="oidcClientSecret")
    def oidc_client_secret(self) -> Optional[pulumi.Input[str]]:
        """
        Client Secret used for OIDC backends
        """
        return pulumi.get(self, "oidc_client_secret")

    @oidc_client_secret.setter
    def oidc_client_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_client_secret", value)

    @property
    @pulumi.getter(name="oidcDiscoveryCaPem")
    def oidc_discovery_ca_pem(self) -> Optional[pulumi.Input[str]]:
        """
        The CA certificate or chain of certificates, in PEM format, to use to validate connections to the OIDC Discovery URL. If not set, system certificates are used
        """
        return pulumi.get(self, "oidc_discovery_ca_pem")

    @oidc_discovery_ca_pem.setter
    def oidc_discovery_ca_pem(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_discovery_ca_pem", value)

    @property
    @pulumi.getter(name="oidcDiscoveryUrl")
    def oidc_discovery_url(self) -> Optional[pulumi.Input[str]]:
        """
        The OIDC Discovery URL, without any .well-known component (base path). Cannot be used in combination with `jwt_validation_pubkeys`
        """
        return pulumi.get(self, "oidc_discovery_url")

    @oidc_discovery_url.setter
    def oidc_discovery_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_discovery_url", value)

    @property
    @pulumi.getter(name="oidcResponseMode")
    def oidc_response_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The response mode to be used in the OAuth2 request. Allowed values are `query` and `form_post`. Defaults to `query`. If using Vault namespaces, and `oidc_response_mode` is `form_post`, then `namespace_in_state` should be set to `false`.
        """
        return pulumi.get(self, "oidc_response_mode")

    @oidc_response_mode.setter
    def oidc_response_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_response_mode", value)

    @property
    @pulumi.getter(name="oidcResponseTypes")
    def oidc_response_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of response types to request. Allowed values are 'code' and 'id_token'. Defaults to `["code"]`. Note: `id_token` may only be used if `oidc_response_mode` is set to `form_post`.
        """
        return pulumi.get(self, "oidc_response_types")

    @oidc_response_types.setter
    def oidc_response_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "oidc_response_types", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        Path to mount the JWT/OIDC auth backend
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Provider specific handling configuration. All values may be strings, and the provider will convert to the appropriate type when configuring Vault.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "provider_config", value)

    @property
    @pulumi.getter
    def tune(self) -> Optional[pulumi.Input['AuthBackendTuneArgs']]:
        return pulumi.get(self, "tune")

    @tune.setter
    def tune(self, value: Optional[pulumi.Input['AuthBackendTuneArgs']]):
        pulumi.set(self, "tune", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of auth backend. Should be one of `jwt` or `oidc`. Default - `jwt`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _AuthBackendState:
    def __init__(__self__, *,
                 accessor: Optional[pulumi.Input[str]] = None,
                 bound_issuer: Optional[pulumi.Input[str]] = None,
                 default_role: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disable_remount: Optional[pulumi.Input[bool]] = None,
                 jwks_ca_pem: Optional[pulumi.Input[str]] = None,
                 jwks_url: Optional[pulumi.Input[str]] = None,
                 jwt_supported_algs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 jwt_validation_pubkeys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 local: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 namespace_in_state: Optional[pulumi.Input[bool]] = None,
                 oidc_client_id: Optional[pulumi.Input[str]] = None,
                 oidc_client_secret: Optional[pulumi.Input[str]] = None,
                 oidc_discovery_ca_pem: Optional[pulumi.Input[str]] = None,
                 oidc_discovery_url: Optional[pulumi.Input[str]] = None,
                 oidc_response_mode: Optional[pulumi.Input[str]] = None,
                 oidc_response_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 provider_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tune: Optional[pulumi.Input['AuthBackendTuneArgs']] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AuthBackend resources.
        :param pulumi.Input[str] accessor: The accessor for this auth method
        :param pulumi.Input[str] bound_issuer: The value against which to match the iss claim in a JWT
        :param pulumi.Input[str] default_role: The default role to use if none is provided during login
        :param pulumi.Input[str] description: The description of the auth backend
        :param pulumi.Input[bool] disable_remount: If set, opts out of mount migration on path updates.
               See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        :param pulumi.Input[str] jwks_ca_pem: The CA certificate or chain of certificates, in PEM format, to use to validate connections to the JWKS URL. If not set, system certificates are used.
        :param pulumi.Input[str] jwks_url: JWKS URL to use to authenticate signatures. Cannot be used with "oidc_discovery_url" or "jwt_validation_pubkeys".
        :param pulumi.Input[Sequence[pulumi.Input[str]]] jwt_supported_algs: A list of supported signing algorithms. Vault 1.1.0 defaults to [RS256] but future or past versions of Vault may differ
        :param pulumi.Input[Sequence[pulumi.Input[str]]] jwt_validation_pubkeys: A list of PEM-encoded public keys to use to authenticate signatures locally. Cannot be used in combination with `oidc_discovery_url`
        :param pulumi.Input[bool] local: Specifies if the auth method is local only.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] namespace_in_state: Pass namespace in the OIDC state parameter instead of as a separate query parameter. With this setting, the allowed redirect URL(s) in Vault and on the provider side should not contain a namespace query parameter. This means only one redirect URL entry needs to be maintained on the OIDC provider side for all vault namespaces that will be authenticating against it. Defaults to true for new configs
               
               * tune - (Optional) Extra configuration block. Structure is documented below.
               
               The `tune` block is used to tune the auth backend:
        :param pulumi.Input[str] oidc_client_id: Client ID used for OIDC backends
        :param pulumi.Input[str] oidc_client_secret: Client Secret used for OIDC backends
        :param pulumi.Input[str] oidc_discovery_ca_pem: The CA certificate or chain of certificates, in PEM format, to use to validate connections to the OIDC Discovery URL. If not set, system certificates are used
        :param pulumi.Input[str] oidc_discovery_url: The OIDC Discovery URL, without any .well-known component (base path). Cannot be used in combination with `jwt_validation_pubkeys`
        :param pulumi.Input[str] oidc_response_mode: The response mode to be used in the OAuth2 request. Allowed values are `query` and `form_post`. Defaults to `query`. If using Vault namespaces, and `oidc_response_mode` is `form_post`, then `namespace_in_state` should be set to `false`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] oidc_response_types: List of response types to request. Allowed values are 'code' and 'id_token'. Defaults to `["code"]`. Note: `id_token` may only be used if `oidc_response_mode` is set to `form_post`.
        :param pulumi.Input[str] path: Path to mount the JWT/OIDC auth backend
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] provider_config: Provider specific handling configuration. All values may be strings, and the provider will convert to the appropriate type when configuring Vault.
        :param pulumi.Input[str] type: Type of auth backend. Should be one of `jwt` or `oidc`. Default - `jwt`
        """
        if accessor is not None:
            pulumi.set(__self__, "accessor", accessor)
        if bound_issuer is not None:
            pulumi.set(__self__, "bound_issuer", bound_issuer)
        if default_role is not None:
            pulumi.set(__self__, "default_role", default_role)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disable_remount is not None:
            pulumi.set(__self__, "disable_remount", disable_remount)
        if jwks_ca_pem is not None:
            pulumi.set(__self__, "jwks_ca_pem", jwks_ca_pem)
        if jwks_url is not None:
            pulumi.set(__self__, "jwks_url", jwks_url)
        if jwt_supported_algs is not None:
            pulumi.set(__self__, "jwt_supported_algs", jwt_supported_algs)
        if jwt_validation_pubkeys is not None:
            pulumi.set(__self__, "jwt_validation_pubkeys", jwt_validation_pubkeys)
        if local is not None:
            pulumi.set(__self__, "local", local)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if namespace_in_state is not None:
            pulumi.set(__self__, "namespace_in_state", namespace_in_state)
        if oidc_client_id is not None:
            pulumi.set(__self__, "oidc_client_id", oidc_client_id)
        if oidc_client_secret is not None:
            pulumi.set(__self__, "oidc_client_secret", oidc_client_secret)
        if oidc_discovery_ca_pem is not None:
            pulumi.set(__self__, "oidc_discovery_ca_pem", oidc_discovery_ca_pem)
        if oidc_discovery_url is not None:
            pulumi.set(__self__, "oidc_discovery_url", oidc_discovery_url)
        if oidc_response_mode is not None:
            pulumi.set(__self__, "oidc_response_mode", oidc_response_mode)
        if oidc_response_types is not None:
            pulumi.set(__self__, "oidc_response_types", oidc_response_types)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if tune is not None:
            pulumi.set(__self__, "tune", tune)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def accessor(self) -> Optional[pulumi.Input[str]]:
        """
        The accessor for this auth method
        """
        return pulumi.get(self, "accessor")

    @accessor.setter
    def accessor(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "accessor", value)

    @property
    @pulumi.getter(name="boundIssuer")
    def bound_issuer(self) -> Optional[pulumi.Input[str]]:
        """
        The value against which to match the iss claim in a JWT
        """
        return pulumi.get(self, "bound_issuer")

    @bound_issuer.setter
    def bound_issuer(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bound_issuer", value)

    @property
    @pulumi.getter(name="defaultRole")
    def default_role(self) -> Optional[pulumi.Input[str]]:
        """
        The default role to use if none is provided during login
        """
        return pulumi.get(self, "default_role")

    @default_role.setter
    def default_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_role", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the auth backend
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="disableRemount")
    def disable_remount(self) -> Optional[pulumi.Input[bool]]:
        """
        If set, opts out of mount migration on path updates.
        See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        """
        return pulumi.get(self, "disable_remount")

    @disable_remount.setter
    def disable_remount(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disable_remount", value)

    @property
    @pulumi.getter(name="jwksCaPem")
    def jwks_ca_pem(self) -> Optional[pulumi.Input[str]]:
        """
        The CA certificate or chain of certificates, in PEM format, to use to validate connections to the JWKS URL. If not set, system certificates are used.
        """
        return pulumi.get(self, "jwks_ca_pem")

    @jwks_ca_pem.setter
    def jwks_ca_pem(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jwks_ca_pem", value)

    @property
    @pulumi.getter(name="jwksUrl")
    def jwks_url(self) -> Optional[pulumi.Input[str]]:
        """
        JWKS URL to use to authenticate signatures. Cannot be used with "oidc_discovery_url" or "jwt_validation_pubkeys".
        """
        return pulumi.get(self, "jwks_url")

    @jwks_url.setter
    def jwks_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jwks_url", value)

    @property
    @pulumi.getter(name="jwtSupportedAlgs")
    def jwt_supported_algs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of supported signing algorithms. Vault 1.1.0 defaults to [RS256] but future or past versions of Vault may differ
        """
        return pulumi.get(self, "jwt_supported_algs")

    @jwt_supported_algs.setter
    def jwt_supported_algs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "jwt_supported_algs", value)

    @property
    @pulumi.getter(name="jwtValidationPubkeys")
    def jwt_validation_pubkeys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of PEM-encoded public keys to use to authenticate signatures locally. Cannot be used in combination with `oidc_discovery_url`
        """
        return pulumi.get(self, "jwt_validation_pubkeys")

    @jwt_validation_pubkeys.setter
    def jwt_validation_pubkeys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "jwt_validation_pubkeys", value)

    @property
    @pulumi.getter
    def local(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies if the auth method is local only.
        """
        return pulumi.get(self, "local")

    @local.setter
    def local(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "local", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="namespaceInState")
    def namespace_in_state(self) -> Optional[pulumi.Input[bool]]:
        """
        Pass namespace in the OIDC state parameter instead of as a separate query parameter. With this setting, the allowed redirect URL(s) in Vault and on the provider side should not contain a namespace query parameter. This means only one redirect URL entry needs to be maintained on the OIDC provider side for all vault namespaces that will be authenticating against it. Defaults to true for new configs

        * tune - (Optional) Extra configuration block. Structure is documented below.

        The `tune` block is used to tune the auth backend:
        """
        return pulumi.get(self, "namespace_in_state")

    @namespace_in_state.setter
    def namespace_in_state(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "namespace_in_state", value)

    @property
    @pulumi.getter(name="oidcClientId")
    def oidc_client_id(self) -> Optional[pulumi.Input[str]]:
        """
        Client ID used for OIDC backends
        """
        return pulumi.get(self, "oidc_client_id")

    @oidc_client_id.setter
    def oidc_client_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_client_id", value)

    @property
    @pulumi.getter(name="oidcClientSecret")
    def oidc_client_secret(self) -> Optional[pulumi.Input[str]]:
        """
        Client Secret used for OIDC backends
        """
        return pulumi.get(self, "oidc_client_secret")

    @oidc_client_secret.setter
    def oidc_client_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_client_secret", value)

    @property
    @pulumi.getter(name="oidcDiscoveryCaPem")
    def oidc_discovery_ca_pem(self) -> Optional[pulumi.Input[str]]:
        """
        The CA certificate or chain of certificates, in PEM format, to use to validate connections to the OIDC Discovery URL. If not set, system certificates are used
        """
        return pulumi.get(self, "oidc_discovery_ca_pem")

    @oidc_discovery_ca_pem.setter
    def oidc_discovery_ca_pem(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_discovery_ca_pem", value)

    @property
    @pulumi.getter(name="oidcDiscoveryUrl")
    def oidc_discovery_url(self) -> Optional[pulumi.Input[str]]:
        """
        The OIDC Discovery URL, without any .well-known component (base path). Cannot be used in combination with `jwt_validation_pubkeys`
        """
        return pulumi.get(self, "oidc_discovery_url")

    @oidc_discovery_url.setter
    def oidc_discovery_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_discovery_url", value)

    @property
    @pulumi.getter(name="oidcResponseMode")
    def oidc_response_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The response mode to be used in the OAuth2 request. Allowed values are `query` and `form_post`. Defaults to `query`. If using Vault namespaces, and `oidc_response_mode` is `form_post`, then `namespace_in_state` should be set to `false`.
        """
        return pulumi.get(self, "oidc_response_mode")

    @oidc_response_mode.setter
    def oidc_response_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_response_mode", value)

    @property
    @pulumi.getter(name="oidcResponseTypes")
    def oidc_response_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of response types to request. Allowed values are 'code' and 'id_token'. Defaults to `["code"]`. Note: `id_token` may only be used if `oidc_response_mode` is set to `form_post`.
        """
        return pulumi.get(self, "oidc_response_types")

    @oidc_response_types.setter
    def oidc_response_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "oidc_response_types", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        Path to mount the JWT/OIDC auth backend
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Provider specific handling configuration. All values may be strings, and the provider will convert to the appropriate type when configuring Vault.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "provider_config", value)

    @property
    @pulumi.getter
    def tune(self) -> Optional[pulumi.Input['AuthBackendTuneArgs']]:
        return pulumi.get(self, "tune")

    @tune.setter
    def tune(self, value: Optional[pulumi.Input['AuthBackendTuneArgs']]):
        pulumi.set(self, "tune", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of auth backend. Should be one of `jwt` or `oidc`. Default - `jwt`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class AuthBackend(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bound_issuer: Optional[pulumi.Input[str]] = None,
                 default_role: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disable_remount: Optional[pulumi.Input[bool]] = None,
                 jwks_ca_pem: Optional[pulumi.Input[str]] = None,
                 jwks_url: Optional[pulumi.Input[str]] = None,
                 jwt_supported_algs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 jwt_validation_pubkeys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 local: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 namespace_in_state: Optional[pulumi.Input[bool]] = None,
                 oidc_client_id: Optional[pulumi.Input[str]] = None,
                 oidc_client_secret: Optional[pulumi.Input[str]] = None,
                 oidc_discovery_ca_pem: Optional[pulumi.Input[str]] = None,
                 oidc_discovery_url: Optional[pulumi.Input[str]] = None,
                 oidc_response_mode: Optional[pulumi.Input[str]] = None,
                 oidc_response_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 provider_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tune: Optional[pulumi.Input[pulumi.InputType['AuthBackendTuneArgs']]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a resource for managing an
        [JWT auth backend within Vault](https://www.vaultproject.io/docs/auth/jwt.html).

        ## Example Usage

        Manage JWT auth backend:

        ```python
        import pulumi
        import pulumi_vault as vault

        example = vault.jwt.AuthBackend("example",
            bound_issuer="https://myco.auth0.com/",
            description="Demonstration of the Terraform JWT auth backend",
            oidc_discovery_url="https://myco.auth0.com/",
            path="jwt")
        ```

        Manage OIDC auth backend:

        ```python
        import pulumi
        import pulumi_vault as vault

        example = vault.jwt.AuthBackend("example",
            bound_issuer="https://myco.auth0.com/",
            description="Demonstration of the Terraform JWT auth backend",
            oidc_client_id="1234567890",
            oidc_client_secret="secret123456",
            oidc_discovery_url="https://myco.auth0.com/",
            path="oidc",
            tune=vault.jwt.AuthBackendTuneArgs(
                listing_visibility="unauth",
            ),
            type="oidc")
        ```

        Configuring the auth backend with a `provider_config:

        ```python
        import pulumi
        import pulumi_vault as vault

        gsuite = vault.jwt.AuthBackend("gsuite",
            description="OIDC backend",
            oidc_discovery_url="https://accounts.google.com",
            path="oidc",
            provider_config={
                "fetch_groups": "true",
                "fetch_user_info": "true",
                "groups_recurse_max_depth": "1",
                "provider": "gsuite",
            },
            type="oidc")
        ```

        ## Import

        JWT auth backend can be imported using the `path`, e.g.

        ```sh
         $ pulumi import vault:jwt/authBackend:AuthBackend oidc oidc
        ```
         or

        ```sh
         $ pulumi import vault:jwt/authBackend:AuthBackend jwt jwt
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bound_issuer: The value against which to match the iss claim in a JWT
        :param pulumi.Input[str] default_role: The default role to use if none is provided during login
        :param pulumi.Input[str] description: The description of the auth backend
        :param pulumi.Input[bool] disable_remount: If set, opts out of mount migration on path updates.
               See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        :param pulumi.Input[str] jwks_ca_pem: The CA certificate or chain of certificates, in PEM format, to use to validate connections to the JWKS URL. If not set, system certificates are used.
        :param pulumi.Input[str] jwks_url: JWKS URL to use to authenticate signatures. Cannot be used with "oidc_discovery_url" or "jwt_validation_pubkeys".
        :param pulumi.Input[Sequence[pulumi.Input[str]]] jwt_supported_algs: A list of supported signing algorithms. Vault 1.1.0 defaults to [RS256] but future or past versions of Vault may differ
        :param pulumi.Input[Sequence[pulumi.Input[str]]] jwt_validation_pubkeys: A list of PEM-encoded public keys to use to authenticate signatures locally. Cannot be used in combination with `oidc_discovery_url`
        :param pulumi.Input[bool] local: Specifies if the auth method is local only.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] namespace_in_state: Pass namespace in the OIDC state parameter instead of as a separate query parameter. With this setting, the allowed redirect URL(s) in Vault and on the provider side should not contain a namespace query parameter. This means only one redirect URL entry needs to be maintained on the OIDC provider side for all vault namespaces that will be authenticating against it. Defaults to true for new configs
               
               * tune - (Optional) Extra configuration block. Structure is documented below.
               
               The `tune` block is used to tune the auth backend:
        :param pulumi.Input[str] oidc_client_id: Client ID used for OIDC backends
        :param pulumi.Input[str] oidc_client_secret: Client Secret used for OIDC backends
        :param pulumi.Input[str] oidc_discovery_ca_pem: The CA certificate or chain of certificates, in PEM format, to use to validate connections to the OIDC Discovery URL. If not set, system certificates are used
        :param pulumi.Input[str] oidc_discovery_url: The OIDC Discovery URL, without any .well-known component (base path). Cannot be used in combination with `jwt_validation_pubkeys`
        :param pulumi.Input[str] oidc_response_mode: The response mode to be used in the OAuth2 request. Allowed values are `query` and `form_post`. Defaults to `query`. If using Vault namespaces, and `oidc_response_mode` is `form_post`, then `namespace_in_state` should be set to `false`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] oidc_response_types: List of response types to request. Allowed values are 'code' and 'id_token'. Defaults to `["code"]`. Note: `id_token` may only be used if `oidc_response_mode` is set to `form_post`.
        :param pulumi.Input[str] path: Path to mount the JWT/OIDC auth backend
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] provider_config: Provider specific handling configuration. All values may be strings, and the provider will convert to the appropriate type when configuring Vault.
        :param pulumi.Input[str] type: Type of auth backend. Should be one of `jwt` or `oidc`. Default - `jwt`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AuthBackendArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a resource for managing an
        [JWT auth backend within Vault](https://www.vaultproject.io/docs/auth/jwt.html).

        ## Example Usage

        Manage JWT auth backend:

        ```python
        import pulumi
        import pulumi_vault as vault

        example = vault.jwt.AuthBackend("example",
            bound_issuer="https://myco.auth0.com/",
            description="Demonstration of the Terraform JWT auth backend",
            oidc_discovery_url="https://myco.auth0.com/",
            path="jwt")
        ```

        Manage OIDC auth backend:

        ```python
        import pulumi
        import pulumi_vault as vault

        example = vault.jwt.AuthBackend("example",
            bound_issuer="https://myco.auth0.com/",
            description="Demonstration of the Terraform JWT auth backend",
            oidc_client_id="1234567890",
            oidc_client_secret="secret123456",
            oidc_discovery_url="https://myco.auth0.com/",
            path="oidc",
            tune=vault.jwt.AuthBackendTuneArgs(
                listing_visibility="unauth",
            ),
            type="oidc")
        ```

        Configuring the auth backend with a `provider_config:

        ```python
        import pulumi
        import pulumi_vault as vault

        gsuite = vault.jwt.AuthBackend("gsuite",
            description="OIDC backend",
            oidc_discovery_url="https://accounts.google.com",
            path="oidc",
            provider_config={
                "fetch_groups": "true",
                "fetch_user_info": "true",
                "groups_recurse_max_depth": "1",
                "provider": "gsuite",
            },
            type="oidc")
        ```

        ## Import

        JWT auth backend can be imported using the `path`, e.g.

        ```sh
         $ pulumi import vault:jwt/authBackend:AuthBackend oidc oidc
        ```
         or

        ```sh
         $ pulumi import vault:jwt/authBackend:AuthBackend jwt jwt
        ```

        :param str resource_name: The name of the resource.
        :param AuthBackendArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuthBackendArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bound_issuer: Optional[pulumi.Input[str]] = None,
                 default_role: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disable_remount: Optional[pulumi.Input[bool]] = None,
                 jwks_ca_pem: Optional[pulumi.Input[str]] = None,
                 jwks_url: Optional[pulumi.Input[str]] = None,
                 jwt_supported_algs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 jwt_validation_pubkeys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 local: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 namespace_in_state: Optional[pulumi.Input[bool]] = None,
                 oidc_client_id: Optional[pulumi.Input[str]] = None,
                 oidc_client_secret: Optional[pulumi.Input[str]] = None,
                 oidc_discovery_ca_pem: Optional[pulumi.Input[str]] = None,
                 oidc_discovery_url: Optional[pulumi.Input[str]] = None,
                 oidc_response_mode: Optional[pulumi.Input[str]] = None,
                 oidc_response_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 provider_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tune: Optional[pulumi.Input[pulumi.InputType['AuthBackendTuneArgs']]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuthBackendArgs.__new__(AuthBackendArgs)

            __props__.__dict__["bound_issuer"] = bound_issuer
            __props__.__dict__["default_role"] = default_role
            __props__.__dict__["description"] = description
            __props__.__dict__["disable_remount"] = disable_remount
            __props__.__dict__["jwks_ca_pem"] = jwks_ca_pem
            __props__.__dict__["jwks_url"] = jwks_url
            __props__.__dict__["jwt_supported_algs"] = jwt_supported_algs
            __props__.__dict__["jwt_validation_pubkeys"] = jwt_validation_pubkeys
            __props__.__dict__["local"] = local
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["namespace_in_state"] = namespace_in_state
            __props__.__dict__["oidc_client_id"] = oidc_client_id
            __props__.__dict__["oidc_client_secret"] = None if oidc_client_secret is None else pulumi.Output.secret(oidc_client_secret)
            __props__.__dict__["oidc_discovery_ca_pem"] = oidc_discovery_ca_pem
            __props__.__dict__["oidc_discovery_url"] = oidc_discovery_url
            __props__.__dict__["oidc_response_mode"] = oidc_response_mode
            __props__.__dict__["oidc_response_types"] = oidc_response_types
            __props__.__dict__["path"] = path
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["tune"] = tune
            __props__.__dict__["type"] = type
            __props__.__dict__["accessor"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["oidcClientSecret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(AuthBackend, __self__).__init__(
            'vault:jwt/authBackend:AuthBackend',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accessor: Optional[pulumi.Input[str]] = None,
            bound_issuer: Optional[pulumi.Input[str]] = None,
            default_role: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            disable_remount: Optional[pulumi.Input[bool]] = None,
            jwks_ca_pem: Optional[pulumi.Input[str]] = None,
            jwks_url: Optional[pulumi.Input[str]] = None,
            jwt_supported_algs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            jwt_validation_pubkeys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            local: Optional[pulumi.Input[bool]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            namespace_in_state: Optional[pulumi.Input[bool]] = None,
            oidc_client_id: Optional[pulumi.Input[str]] = None,
            oidc_client_secret: Optional[pulumi.Input[str]] = None,
            oidc_discovery_ca_pem: Optional[pulumi.Input[str]] = None,
            oidc_discovery_url: Optional[pulumi.Input[str]] = None,
            oidc_response_mode: Optional[pulumi.Input[str]] = None,
            oidc_response_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            path: Optional[pulumi.Input[str]] = None,
            provider_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            tune: Optional[pulumi.Input[pulumi.InputType['AuthBackendTuneArgs']]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'AuthBackend':
        """
        Get an existing AuthBackend resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] accessor: The accessor for this auth method
        :param pulumi.Input[str] bound_issuer: The value against which to match the iss claim in a JWT
        :param pulumi.Input[str] default_role: The default role to use if none is provided during login
        :param pulumi.Input[str] description: The description of the auth backend
        :param pulumi.Input[bool] disable_remount: If set, opts out of mount migration on path updates.
               See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        :param pulumi.Input[str] jwks_ca_pem: The CA certificate or chain of certificates, in PEM format, to use to validate connections to the JWKS URL. If not set, system certificates are used.
        :param pulumi.Input[str] jwks_url: JWKS URL to use to authenticate signatures. Cannot be used with "oidc_discovery_url" or "jwt_validation_pubkeys".
        :param pulumi.Input[Sequence[pulumi.Input[str]]] jwt_supported_algs: A list of supported signing algorithms. Vault 1.1.0 defaults to [RS256] but future or past versions of Vault may differ
        :param pulumi.Input[Sequence[pulumi.Input[str]]] jwt_validation_pubkeys: A list of PEM-encoded public keys to use to authenticate signatures locally. Cannot be used in combination with `oidc_discovery_url`
        :param pulumi.Input[bool] local: Specifies if the auth method is local only.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] namespace_in_state: Pass namespace in the OIDC state parameter instead of as a separate query parameter. With this setting, the allowed redirect URL(s) in Vault and on the provider side should not contain a namespace query parameter. This means only one redirect URL entry needs to be maintained on the OIDC provider side for all vault namespaces that will be authenticating against it. Defaults to true for new configs
               
               * tune - (Optional) Extra configuration block. Structure is documented below.
               
               The `tune` block is used to tune the auth backend:
        :param pulumi.Input[str] oidc_client_id: Client ID used for OIDC backends
        :param pulumi.Input[str] oidc_client_secret: Client Secret used for OIDC backends
        :param pulumi.Input[str] oidc_discovery_ca_pem: The CA certificate or chain of certificates, in PEM format, to use to validate connections to the OIDC Discovery URL. If not set, system certificates are used
        :param pulumi.Input[str] oidc_discovery_url: The OIDC Discovery URL, without any .well-known component (base path). Cannot be used in combination with `jwt_validation_pubkeys`
        :param pulumi.Input[str] oidc_response_mode: The response mode to be used in the OAuth2 request. Allowed values are `query` and `form_post`. Defaults to `query`. If using Vault namespaces, and `oidc_response_mode` is `form_post`, then `namespace_in_state` should be set to `false`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] oidc_response_types: List of response types to request. Allowed values are 'code' and 'id_token'. Defaults to `["code"]`. Note: `id_token` may only be used if `oidc_response_mode` is set to `form_post`.
        :param pulumi.Input[str] path: Path to mount the JWT/OIDC auth backend
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] provider_config: Provider specific handling configuration. All values may be strings, and the provider will convert to the appropriate type when configuring Vault.
        :param pulumi.Input[str] type: Type of auth backend. Should be one of `jwt` or `oidc`. Default - `jwt`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuthBackendState.__new__(_AuthBackendState)

        __props__.__dict__["accessor"] = accessor
        __props__.__dict__["bound_issuer"] = bound_issuer
        __props__.__dict__["default_role"] = default_role
        __props__.__dict__["description"] = description
        __props__.__dict__["disable_remount"] = disable_remount
        __props__.__dict__["jwks_ca_pem"] = jwks_ca_pem
        __props__.__dict__["jwks_url"] = jwks_url
        __props__.__dict__["jwt_supported_algs"] = jwt_supported_algs
        __props__.__dict__["jwt_validation_pubkeys"] = jwt_validation_pubkeys
        __props__.__dict__["local"] = local
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["namespace_in_state"] = namespace_in_state
        __props__.__dict__["oidc_client_id"] = oidc_client_id
        __props__.__dict__["oidc_client_secret"] = oidc_client_secret
        __props__.__dict__["oidc_discovery_ca_pem"] = oidc_discovery_ca_pem
        __props__.__dict__["oidc_discovery_url"] = oidc_discovery_url
        __props__.__dict__["oidc_response_mode"] = oidc_response_mode
        __props__.__dict__["oidc_response_types"] = oidc_response_types
        __props__.__dict__["path"] = path
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["tune"] = tune
        __props__.__dict__["type"] = type
        return AuthBackend(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def accessor(self) -> pulumi.Output[str]:
        """
        The accessor for this auth method
        """
        return pulumi.get(self, "accessor")

    @property
    @pulumi.getter(name="boundIssuer")
    def bound_issuer(self) -> pulumi.Output[Optional[str]]:
        """
        The value against which to match the iss claim in a JWT
        """
        return pulumi.get(self, "bound_issuer")

    @property
    @pulumi.getter(name="defaultRole")
    def default_role(self) -> pulumi.Output[Optional[str]]:
        """
        The default role to use if none is provided during login
        """
        return pulumi.get(self, "default_role")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the auth backend
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="disableRemount")
    def disable_remount(self) -> pulumi.Output[Optional[bool]]:
        """
        If set, opts out of mount migration on path updates.
        See here for more info on [Mount Migration](https://www.vaultproject.io/docs/concepts/mount-migration)
        """
        return pulumi.get(self, "disable_remount")

    @property
    @pulumi.getter(name="jwksCaPem")
    def jwks_ca_pem(self) -> pulumi.Output[Optional[str]]:
        """
        The CA certificate or chain of certificates, in PEM format, to use to validate connections to the JWKS URL. If not set, system certificates are used.
        """
        return pulumi.get(self, "jwks_ca_pem")

    @property
    @pulumi.getter(name="jwksUrl")
    def jwks_url(self) -> pulumi.Output[Optional[str]]:
        """
        JWKS URL to use to authenticate signatures. Cannot be used with "oidc_discovery_url" or "jwt_validation_pubkeys".
        """
        return pulumi.get(self, "jwks_url")

    @property
    @pulumi.getter(name="jwtSupportedAlgs")
    def jwt_supported_algs(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of supported signing algorithms. Vault 1.1.0 defaults to [RS256] but future or past versions of Vault may differ
        """
        return pulumi.get(self, "jwt_supported_algs")

    @property
    @pulumi.getter(name="jwtValidationPubkeys")
    def jwt_validation_pubkeys(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of PEM-encoded public keys to use to authenticate signatures locally. Cannot be used in combination with `oidc_discovery_url`
        """
        return pulumi.get(self, "jwt_validation_pubkeys")

    @property
    @pulumi.getter
    def local(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies if the auth method is local only.
        """
        return pulumi.get(self, "local")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="namespaceInState")
    def namespace_in_state(self) -> pulumi.Output[Optional[bool]]:
        """
        Pass namespace in the OIDC state parameter instead of as a separate query parameter. With this setting, the allowed redirect URL(s) in Vault and on the provider side should not contain a namespace query parameter. This means only one redirect URL entry needs to be maintained on the OIDC provider side for all vault namespaces that will be authenticating against it. Defaults to true for new configs

        * tune - (Optional) Extra configuration block. Structure is documented below.

        The `tune` block is used to tune the auth backend:
        """
        return pulumi.get(self, "namespace_in_state")

    @property
    @pulumi.getter(name="oidcClientId")
    def oidc_client_id(self) -> pulumi.Output[Optional[str]]:
        """
        Client ID used for OIDC backends
        """
        return pulumi.get(self, "oidc_client_id")

    @property
    @pulumi.getter(name="oidcClientSecret")
    def oidc_client_secret(self) -> pulumi.Output[Optional[str]]:
        """
        Client Secret used for OIDC backends
        """
        return pulumi.get(self, "oidc_client_secret")

    @property
    @pulumi.getter(name="oidcDiscoveryCaPem")
    def oidc_discovery_ca_pem(self) -> pulumi.Output[Optional[str]]:
        """
        The CA certificate or chain of certificates, in PEM format, to use to validate connections to the OIDC Discovery URL. If not set, system certificates are used
        """
        return pulumi.get(self, "oidc_discovery_ca_pem")

    @property
    @pulumi.getter(name="oidcDiscoveryUrl")
    def oidc_discovery_url(self) -> pulumi.Output[Optional[str]]:
        """
        The OIDC Discovery URL, without any .well-known component (base path). Cannot be used in combination with `jwt_validation_pubkeys`
        """
        return pulumi.get(self, "oidc_discovery_url")

    @property
    @pulumi.getter(name="oidcResponseMode")
    def oidc_response_mode(self) -> pulumi.Output[Optional[str]]:
        """
        The response mode to be used in the OAuth2 request. Allowed values are `query` and `form_post`. Defaults to `query`. If using Vault namespaces, and `oidc_response_mode` is `form_post`, then `namespace_in_state` should be set to `false`.
        """
        return pulumi.get(self, "oidc_response_mode")

    @property
    @pulumi.getter(name="oidcResponseTypes")
    def oidc_response_types(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of response types to request. Allowed values are 'code' and 'id_token'. Defaults to `["code"]`. Note: `id_token` may only be used if `oidc_response_mode` is set to `form_post`.
        """
        return pulumi.get(self, "oidc_response_types")

    @property
    @pulumi.getter
    def path(self) -> pulumi.Output[Optional[str]]:
        """
        Path to mount the JWT/OIDC auth backend
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Provider specific handling configuration. All values may be strings, and the provider will convert to the appropriate type when configuring Vault.
        """
        return pulumi.get(self, "provider_config")

    @property
    @pulumi.getter
    def tune(self) -> pulumi.Output['outputs.AuthBackendTune']:
        return pulumi.get(self, "tune")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[Optional[str]]:
        """
        Type of auth backend. Should be one of `jwt` or `oidc`. Default - `jwt`
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['SecretRoleArgs', 'SecretRole']

@pulumi.input_type
class SecretRoleArgs:
    def __init__(__self__, *,
                 backend: Optional[pulumi.Input[str]] = None,
                 max_ttl: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 team_id: Optional[pulumi.Input[str]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 user_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SecretRole resource.
        :param pulumi.Input[str] backend: The path of the Terraform Cloud Secret Backend the role belongs to.
        :param pulumi.Input[int] max_ttl: Maximum TTL for leases associated with this role, in seconds.
        :param pulumi.Input[str] name: The name of an existing role against which to create this Terraform Cloud credential
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] organization: Name of the Terraform Cloud or Enterprise organization
        :param pulumi.Input[str] team_id: ID of the Terraform Cloud or Enterprise team under organization (e.g., settings/teams/team-xxxxxxxxxxxxx)
        :param pulumi.Input[int] ttl: Specifies the TTL for this role.
        :param pulumi.Input[str] user_id: ID of the Terraform Cloud or Enterprise user (e.g., user-xxxxxxxxxxxxxxxx)
        """
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if max_ttl is not None:
            pulumi.set(__self__, "max_ttl", max_ttl)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[str]]:
        """
        The path of the Terraform Cloud Secret Backend the role belongs to.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter(name="maxTtl")
    def max_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        Maximum TTL for leases associated with this role, in seconds.
        """
        return pulumi.get(self, "max_ttl")

    @max_ttl.setter
    def max_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_ttl", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of an existing role against which to create this Terraform Cloud credential
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Terraform Cloud or Enterprise organization
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the Terraform Cloud or Enterprise team under organization (e.g., settings/teams/team-xxxxxxxxxxxxx)
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "team_id", value)

    @property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the TTL for this role.
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ttl", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the Terraform Cloud or Enterprise user (e.g., user-xxxxxxxxxxxxxxxx)
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _SecretRoleState:
    def __init__(__self__, *,
                 backend: Optional[pulumi.Input[str]] = None,
                 max_ttl: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 team_id: Optional[pulumi.Input[str]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 user_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SecretRole resources.
        :param pulumi.Input[str] backend: The path of the Terraform Cloud Secret Backend the role belongs to.
        :param pulumi.Input[int] max_ttl: Maximum TTL for leases associated with this role, in seconds.
        :param pulumi.Input[str] name: The name of an existing role against which to create this Terraform Cloud credential
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] organization: Name of the Terraform Cloud or Enterprise organization
        :param pulumi.Input[str] team_id: ID of the Terraform Cloud or Enterprise team under organization (e.g., settings/teams/team-xxxxxxxxxxxxx)
        :param pulumi.Input[int] ttl: Specifies the TTL for this role.
        :param pulumi.Input[str] user_id: ID of the Terraform Cloud or Enterprise user (e.g., user-xxxxxxxxxxxxxxxx)
        """
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if max_ttl is not None:
            pulumi.set(__self__, "max_ttl", max_ttl)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[str]]:
        """
        The path of the Terraform Cloud Secret Backend the role belongs to.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter(name="maxTtl")
    def max_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        Maximum TTL for leases associated with this role, in seconds.
        """
        return pulumi.get(self, "max_ttl")

    @max_ttl.setter
    def max_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_ttl", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of an existing role against which to create this Terraform Cloud credential
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Terraform Cloud or Enterprise organization
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the Terraform Cloud or Enterprise team under organization (e.g., settings/teams/team-xxxxxxxxxxxxx)
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "team_id", value)

    @property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the TTL for this role.
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ttl", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the Terraform Cloud or Enterprise user (e.g., user-xxxxxxxxxxxxxxxx)
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_id", value)


class SecretRole(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 max_ttl: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 team_id: Optional[pulumi.Input[str]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        test = vault.terraformcloud.SecretBackend("test",
            backend="terraform",
            description="Manages the Terraform Cloud backend",
            token="V0idfhi2iksSDU234ucdbi2nidsi...")
        example = vault.terraformcloud.SecretRole("example",
            backend=test.backend,
            organization="example-organization-name",
            team_id="team-ieF4isC...")
        ```

        ## Import

        Terraform Cloud secret backend roles can be imported using the `backend`, `/roles/`, and the `name` e.g.

        ```sh
         $ pulumi import vault:terraformcloud/secretRole:SecretRole example terraform/roles/my-role
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backend: The path of the Terraform Cloud Secret Backend the role belongs to.
        :param pulumi.Input[int] max_ttl: Maximum TTL for leases associated with this role, in seconds.
        :param pulumi.Input[str] name: The name of an existing role against which to create this Terraform Cloud credential
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] organization: Name of the Terraform Cloud or Enterprise organization
        :param pulumi.Input[str] team_id: ID of the Terraform Cloud or Enterprise team under organization (e.g., settings/teams/team-xxxxxxxxxxxxx)
        :param pulumi.Input[int] ttl: Specifies the TTL for this role.
        :param pulumi.Input[str] user_id: ID of the Terraform Cloud or Enterprise user (e.g., user-xxxxxxxxxxxxxxxx)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SecretRoleArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        test = vault.terraformcloud.SecretBackend("test",
            backend="terraform",
            description="Manages the Terraform Cloud backend",
            token="V0idfhi2iksSDU234ucdbi2nidsi...")
        example = vault.terraformcloud.SecretRole("example",
            backend=test.backend,
            organization="example-organization-name",
            team_id="team-ieF4isC...")
        ```

        ## Import

        Terraform Cloud secret backend roles can be imported using the `backend`, `/roles/`, and the `name` e.g.

        ```sh
         $ pulumi import vault:terraformcloud/secretRole:SecretRole example terraform/roles/my-role
        ```

        :param str resource_name: The name of the resource.
        :param SecretRoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecretRoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 max_ttl: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 team_id: Optional[pulumi.Input[str]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecretRoleArgs.__new__(SecretRoleArgs)

            __props__.__dict__["backend"] = backend
            __props__.__dict__["max_ttl"] = max_ttl
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["organization"] = organization
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["ttl"] = ttl
            __props__.__dict__["user_id"] = user_id
        super(SecretRole, __self__).__init__(
            'vault:terraformcloud/secretRole:SecretRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backend: Optional[pulumi.Input[str]] = None,
            max_ttl: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            team_id: Optional[pulumi.Input[str]] = None,
            ttl: Optional[pulumi.Input[int]] = None,
            user_id: Optional[pulumi.Input[str]] = None) -> 'SecretRole':
        """
        Get an existing SecretRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backend: The path of the Terraform Cloud Secret Backend the role belongs to.
        :param pulumi.Input[int] max_ttl: Maximum TTL for leases associated with this role, in seconds.
        :param pulumi.Input[str] name: The name of an existing role against which to create this Terraform Cloud credential
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] organization: Name of the Terraform Cloud or Enterprise organization
        :param pulumi.Input[str] team_id: ID of the Terraform Cloud or Enterprise team under organization (e.g., settings/teams/team-xxxxxxxxxxxxx)
        :param pulumi.Input[int] ttl: Specifies the TTL for this role.
        :param pulumi.Input[str] user_id: ID of the Terraform Cloud or Enterprise user (e.g., user-xxxxxxxxxxxxxxxx)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecretRoleState.__new__(_SecretRoleState)

        __props__.__dict__["backend"] = backend
        __props__.__dict__["max_ttl"] = max_ttl
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["organization"] = organization
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["ttl"] = ttl
        __props__.__dict__["user_id"] = user_id
        return SecretRole(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def backend(self) -> pulumi.Output[Optional[str]]:
        """
        The path of the Terraform Cloud Secret Backend the role belongs to.
        """
        return pulumi.get(self, "backend")

    @property
    @pulumi.getter(name="maxTtl")
    def max_ttl(self) -> pulumi.Output[Optional[int]]:
        """
        Maximum TTL for leases associated with this role, in seconds.
        """
        return pulumi.get(self, "max_ttl")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of an existing role against which to create this Terraform Cloud credential
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[Optional[str]]:
        """
        Name of the Terraform Cloud or Enterprise organization
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[Optional[str]]:
        """
        ID of the Terraform Cloud or Enterprise team under organization (e.g., settings/teams/team-xxxxxxxxxxxxx)
        """
        return pulumi.get(self, "team_id")

    @property
    @pulumi.getter
    def ttl(self) -> pulumi.Output[Optional[int]]:
        """
        Specifies the TTL for this role.
        """
        return pulumi.get(self, "ttl")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[Optional[str]]:
        """
        ID of the Terraform Cloud or Enterprise user (e.g., user-xxxxxxxxxxxxxxxx)
        """
        return pulumi.get(self, "user_id")

